﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace JacekMatulewski.WpfControls
{
    /// <summary>
    /// Interaction logic for FileChooserDialog.xaml
    /// </summary>
    public partial class FileChooser : UserControl //nie trzeba implementować INotifyPropertyChanged, bo jest UserControl
    //zob. uwagi na temat INotifyPropertyChanged w https://stackoverflow.com/questions/28111446/define-command-binding-in-user-control
    {
        public FileChooser()
        {
            InitializeComponent();
        }

        public static DependencyProperty FilePathProperty
            = DependencyProperty.Register(
                "FilePath",
                typeof(string),
                typeof(FileChooser));

        public string FilePath
        {
            get
            {
                return (string)GetValue(FilePathProperty);
            }
            set
            {
                SetValue(FilePathProperty, value);

                //uzgadnianie wewnętrznych kontrolek
                textBox.Text = value;

                //zdarzenie
                FilePathChangedEventArgs args = new FilePathChangedEventArgs() { FilePath = value };
                args.RoutedEvent = FilePathChangedEvent;
                RaiseEvent(args);

                //polecenie
                if (Command != null)
                {
                    if (Command.CanExecute(FilePath))
                    {
                        Command.Execute(FilePath);
                    }
                }
            }
        }

        public class FilePathChangedEventArgs : RoutedEventArgs
        {
            public string FilePath;
        }

        public delegate void FilePathChangedEventHandler(object sender, FilePathChangedEventArgs e);
        //public event FilePathChangedEventHandler FilePathChanged;
        //public event EventHandler<FilePathChangedEventArgs> FilePathChanged; //por. http://www.c-sharpcorner.com/UploadFile/mahesh/user-control-in-wpf/
        //public event EventHandler<FilePathChangedEventArgs> FilePathChanged;

        public static readonly RoutedEvent FilePathChangedEvent =
            EventManager.RegisterRoutedEvent("FilePathChanged", RoutingStrategy.Tunnel,
            typeof(FilePathChangedEventHandler), typeof(FileChooser));

        public event FilePathChangedEventHandler FilePathChanged
        {
            add { AddHandler(FilePathChangedEvent, value); }
            remove { RemoveHandler(FilePathChangedEvent, value); }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Microsoft.Win32.OpenFileDialog ofd = new Microsoft.Win32.OpenFileDialog();
            ofd.Filter = this.Filter;
            ofd.FilterIndex = this.FilterIndex;
            ofd.FileName = FilePath;
            bool? result = ofd.ShowDialog();
            if (result.HasValue && result.Value)
            {
                FilePath = ofd.FileName;
            }
        }

        public static DependencyProperty FilterProperty
            = DependencyProperty.Register(
                "Filter",
                typeof(string),
                typeof(FileChooser));

        public string Filter
        {
            get
            {
                return (string)GetValue(FilterProperty);
            }
            set
            {
                SetValue(FilterProperty, value);
            }
        }

        public static DependencyProperty FilterIndexProperty
            = DependencyProperty.Register(
                "FilterIndex",
                typeof(int),
                typeof(FileChooser));

        public int FilterIndex
        {
            get
            {
                return (int)GetValue(FilterIndexProperty);
            }
            set
            {
                SetValue(FilterIndexProperty, value);
            }
        }

        public static readonly DependencyProperty CommandProperty
            = DependencyProperty.Register(
                "Command",
                typeof(ICommand),
                typeof(FileChooser));

        public ICommand Command
        {
            get
            {
                return (ICommand)GetValue(CommandProperty);
            }
            set
            {
                SetValue(CommandProperty, value);
            }
        }

        public static readonly DependencyProperty LabelProperty =
            DependencyProperty.Register("Label", typeof(string), typeof(FileChooser));

        public string Label
        {
            get 
            { 
                return (string)GetValue(LabelProperty); 
            }
            set 
            {
                
                SetValue(LabelProperty, value); 
            }
        }
    }
}
